@@ -12,6 +12,8 @@ from ..xmd import _special_funcs
 
 class BaseSlides:
     def __init__(self):
+        self._warnings = [] # Will be printed at end of building slides
+        self._uid = f'{self.__class__.__name__}-{id(self)}' # Unique ID for this instance to have CSS, should be before settings
         self.__widgets = Widgets()
         self.__screenshot = ScreenShot(self.__widgets)
         self.clipboard_image = self.__screenshot.clipboard_image # For easy access
@@ -56,6 +58,11 @@ class BaseSlides:
         else:
             self.toast_html.layout.visibility = 'hidden'
     
+    @property
+    def uid(self):
+        "Unique CCS class for slides."
+        return self._uid
+    
     @property
     def css_styles(self):
         """CSS styles for markdown or `classed` command."""
@@ -78,6 +85,7 @@ class BaseSlides:
          'slides-only'      | Text will not appear in exported html report.
          'report-only'      | Text will not appear on slides. Use to fill content in report.
          'export-only'      | Hidden on main slides, but will appear in exported slides/report.
+         'jupyter-only'     | Hidden on exported slides/report, but will appear on main slides.
          'page-break'       | Report will break page in print after object with this class.
          'block'            | Block of text/objects
          'block-[color]'    | Block of text/objects with specific background color from red,
@@ -194,7 +202,14 @@ class BaseSlides:
             - Do not use this to change global state of slides, because that will affect all slides.
             - This can be used single time per slide, overwriting previous function.
         """
-        self.verify_running('Dynamic content can only be created under a slide constructor!')
+        for name in ['write','print','display']:
+            if name in func.__code__.co_names:
+                self._warnings.append(f'UserWarning: Output of `{name}` function under `on_load` may be lost while presenting. I hope you know what you are doing!')
+        
+        if 'settings' in func.__code__.co_names:
+            self._warnings.append(f'UserWarning: Changing settings under `on_load` may have side effects on all slides. I hope you know what you are doing!')
+        
+        self.verify_running('on_load decorator can only be used inside slide constructor!')
         self.running._on_load_private(func) # This to make sure if code is correct before adding it to slide
     
     def on_refresh(self,func):
@@ -224,8 +239,14 @@ class BaseSlides:
     
     def _dynamic_private(self, func, tag = None, hide_refresher = False):
         "Not for user use, internal function for other dynamic content decorators with their own tags."
-        self.verify_running('Dynamic content can only be created under a slide constructor!')
+        self.verify_running('Dynamic content can only be used inside slide constructor!')
         return self.running._dynamic_private(func, tag = tag, hide_refresher = hide_refresher)
+    
+    def _called_from_notenook(self, func_name):
+        last_hist = list(self.shell.history_manager.get_range())[-1][-1]
+        if re.findall(rf'{func_name}\(|{func_name}\s+\(', last_hist):
+            return True
+        return False
         
     def from_markdown(self, start, file_or_str, trusted = False):
         """You can create slides from a markdown file or tex block as well. It creates slides `start + (0,1,2,3...)` in order.
@@ -276,7 +297,7 @@ class BaseSlides:
             raise Exception('Python/IPython REPL cannot show slides. Use IPython notebook instead.')
         
         if not isinstance(file_or_str, str): #check path later or it will throw error
-            raise ValueError(f"file_or_str expects a makrdown file path(str) or text block, got {file_or_str!r}")
+            raise TypeError(f"file_or_str expects a makrdown file path(str) or text block, got {file_or_str!r}")
         
         if not trusted:
             try: # Try becuase long string will through error for path
@@ -315,8 +336,7 @@ class BaseSlides:
                 self._slide(f'{i} -m', chunk)
         
         # Display slides if called form Notebook Cell only
-        last_hist = list(self.shell.history_manager.get_range())[-1][-1]
-        if re.findall(r'from_markdown\(|from_markdown\s+\(', last_hist):
+        if self._called_from_notenook('from_markdown'):
             self.shell.events.register('post_run_cell', self._post_run_cell)
         
         # Return refrence to slides for quick update, frames should be accessed by slide.frames
@@ -330,7 +350,7 @@ class BaseSlides:
         with self.set_dir(os.path.split(__file__)[0]):
             file = '../_demo.py'
             raw_source = self.source.from_file(file).raw
-            N = raw_source.count('auto.') # Count number of slides
+            N = raw_source.count('auto.') + raw_source.count('\n---') + 1 # Count number of slides, +1 for run_cell there
             self.create(*range(N)) # Create slides first, this is faster
             self.shell.run_line_magic('run', file) # Run demo in same namespace
             
@@ -341,7 +361,7 @@ class BaseSlides:
         "Create presentation from docs of IPySlides."
         self.close_view() # Close any previous view to speed up loading 10x faster on average
         self.clear() # Clear previous content
-        self.create(*range(13)) # Create slides faster
+        self.create(*range(22)) # Create slides faster
         
         from ..core import Slides
         self.settings.set_footer('IPySlides Documentation')
@@ -396,8 +416,8 @@ class BaseSlides:
                 
         with auto.slide():
             self.write('## Useful Functions for Rich Content section`?Useful Functions for alert`Rich Content`?`')
-            members = ['alert','block', 'bokeh2html', 'bullets','cite','classed',
-                       'color', 'cols', 'details', 'doc','sub','sup', 'today', 'enable_zoom', 'format_css', 'format_html', 'highlight',
+            members = ['alt', 'alert','block', 'bokeh2html', 'bullets','cite','classed',
+                       'color', 'cols', 'details', 'doc','sub','sup', 'today', 'enable_zoom', 'format_css', 'highlight',
                        'html', 'iframe', 'image', 'keep_format', 'notify', 'plt2html', 'raw', 'rows',
                         'section', 'set_citations', 'set_dir', 'sig', 'textbox', 'suppress_output','suppress_stdout','svg', 'vspace']
             self.doc(self.clipboard_image,'Slides').display()
