@@ -1,5 +1,5 @@
 """
-Author Notes: Classes in this module should only be instantiated in LiveSlide class or it's parent class
+Author Notes: Classes in this module should only be instantiated in Slides class or it's parent class
 and then provided to other classes via composition, not inheritance.
 """
 
@@ -15,7 +15,7 @@ from . import intro
 
 class ScreenShot:
     def __init__(self, _instanceWidgets):
-        "Instnace should be inside `LiveSlide` class."
+        "Instnace should be inside `Slides` class."
         self.widgets = _instanceWidgets
         self.btn_cap_all = self.widgets.buttons.cap_all
         self.btn_pdf = self.widgets.buttons.pdf
@@ -79,6 +79,8 @@ class ScreenShot:
         - quality: 95; In term of current screen. Will not chnage too much above 95. 
         - bbox: None; None for full screen on any platform. Given screen position of slides in pixels as [left,top,right,bottom].
         > Note: Auto detection of bbox in frontends where javascript runs is under progress. """
+        if load_time < 0.1:
+            return print("load_time must be greater than 0.1 to at least load the slide")
         if bbox and len(bbox) != 4:
             return print("bbox expects [left,top,right,bottom] in integers")
         self.__capture_settings = {'load_time':load_time,'quality':quality,'bbox':bbox if bbox else self.screen_bbox} # get full if none given
