@@ -1,10 +1,9 @@
 """Slide Object, should not be instantiated directly"""
 
-import sys
+import sys, time
 from contextlib import contextmanager
 from ipywidgets import Output, Layout, Button, HBox
 
-
 from IPython.display import display
 from IPython.utils.capture import capture_output
 from IPython.core.ultratb import FormattedTB
@@ -25,14 +24,10 @@ def _expand_cols(outputs, context):
             new_outputs.append(out)
     return new_outputs
 
-
 class DynamicRefresh:
     "DynamicRefresh is a display for a function that is executed when refresh button is clicked. Should not be instantiated directly."
     def __init__(self, func, slide):
-        if getattr(slide._app, '_in_cols', False):
-            raise Exception('Dynamically refreshable content cannot be written inside Columns!')
-        
-        if getattr(slide._app, '_in_dproxy', None):
+        if getattr(slide._app, '_in_dproxy', None): # raise this also because dictionary size get changed during iteration if nested
             raise Exception('Dynamically refreshable content cannot be written inside another same type!')
         
         self._func = func
@@ -49,13 +44,12 @@ class DynamicRefresh:
         
         self._slide._app._in_dproxy = self
         try: # Initail error in cell to verify code is correct
-            with capture_output():
+            with capture_output() as cap:
                 self._func()
-        except Exception as e:
-            raise Exception(f'{e}')
+            if cap.stderr: raise Exception(cap.stderr)
         finally:
             self._slide._app._in_dproxy = None
-            
+        
         self._btn.on_click(self._on_click)
     
     def _ipython_display_(self):            
@@ -153,6 +147,9 @@ class Proxy:
         if getattr(slide._app, '_in_dproxy', None):
             raise RuntimeError("Can't place proxy inside a refreshable function.")
         
+        if getattr(slide._app, '_in_proxy', None):
+            raise RuntimeError("Can't place proxy inside another proxy being captured.")
+        
         self._text = text
         self._slide = slide
         self._outputs = []
@@ -244,18 +241,32 @@ class Slide:
         return Proxy(text, self) # get auto displayed
         
     def _on_load_private(self, func):
+        old = self._app.running
+        self._app._running_slide = None # temporarily set it to None to avoid dynamic things inside on_load, as it will not be running on load
         try: # check if code is correct
             with capture_output():
                 func()
         except Exception as e:
-            raise Exception(f'{e}')
+            if 'constructor' in str(e):
+                raise RuntimeError(f'{e}\nYou may be trying to put dynamic content inside on_load which is restricted!')
+            raise e
+        finally:
+            self._app._running_slide = old
+        # This should be outside the try/except block even after finally, if successful, only then assign it.
         self._on_load = func # This will be called in main app
     
     def run_on_load(self):
-        "Called when a slide is loaded into view."
-        if hasattr(self,'_on_load') and callable(self._on_load):
-            self._on_load()
-    
+        "Called when a slide is loaded into view. Use it to register notifications etc."
+        self._widget.layout.height = '100%' # Trigger a height change to reset scroll position
+        start = time.time()
+        try: # Try is to handle errors in on_load, not for attribute errors, and also finally to reset height
+            if hasattr(self,'_on_load') and callable(self._on_load):
+                self._on_load() # Now no need to raise Error as it is already done in _on_load_private, and no one can handle it either
+        finally:
+            if (t := time.time() - start) < 0.05: # Could not have enought time to resend another event
+                time.sleep(0.05 - t) # Wait at least 50ms, (it does not effect anything else) for the height to change from previous trigger
+            self._widget.layout.height = 'auto' # Reset height to auto
+        
     def __repr__(self):
         return f'Slide(number = {self._number}, label = {self.label!r}, index = {self._index})'
     
@@ -289,6 +300,10 @@ class Slide:
             self._app._running_slide = None
             self._contents = _expand_cols(captured.outputs, self) # Expand columns  
         
+        if self._app._warnings:
+            print(*self._app._warnings, sep='\n\n')
+            self._app._warnings = [] # Reset warnings
+        
         
     def update_display(self, go_there = True):
         "Update display of this slide."
@@ -296,10 +311,10 @@ class Slide:
             self.clear_display(wait = True) # Clear and go there, wait to avoid blinking
         else:
             self._widget.clear_output(wait = True) # Clear, but don't go there
-        
+
         with self._widget:
             display(*self.contents)
-            for dp in self._dproxies.values():
+            for dp in self._dproxies.values(): 
                 dp.update_display() # Update display to show new output as well
             
             if self._citations and (self._app._citation_mode == 'footnote'):
@@ -391,10 +406,6 @@ class Slide:
         else:
             return self._app.source.from_string('Source of a slide only exits if it is NOT created (most recently) using @Slides.frames decorator\n',language = 'markdown')
     
-    def show(self):
-        self.update_display() # Needs to not discard widgets there
-        return display(self._widget)
-    
     def _set_overall_css(self, css_dict={}):
         self.__class__._overall_css = html('style','') # Reset overall CSS
         old_slide_css = self._css # Save old slide CSS without overall CSS
@@ -417,29 +428,33 @@ class Slide:
                 self._app.widgets.outputs.slide.clear_output(wait = False)
                 with self._app.widgets.outputs.slide:
                     display(self.animation, self._css)
+    
+    def _instance_animation(self,name):
+        "Create unique animation for this slide instance on fly"
+        return styles.animations[name].replace('.SlideBox',f'.{self._app.uid} .SlideBox')
         
     def _set_overall_animation(self, main = 'slide_h',frame = 'slide_v'):
         "Set animation for all slides."
         if main is None:
             self.__class__._animations['main'] = ''
         elif main in styles.animations:
-            self.__class__._animations['main'] = styles.animations[main]
+            self.__class__._animations['main'] = self._instance_animation(main)
         else:
-            raise ValueError(f'Animation {main!r} not found. Use None to remove animation or one of {tuple(styles.animations.keys())}')
+            raise KeyError(f'Animation {main!r} not found. Use None to remove animation or one of {tuple(styles.animations.keys())}')
             
         if frame is None:
             self.__class__._animations['frame'] = ''
         elif frame in styles.animations:
-            self.__class__._animations['frame'] = styles.animations[frame]
+            self.__class__._animations['frame'] = self._instance_animation(frame)
         else:
-            raise ValueError(f'Animation {frame!r} not found. Use None to remove animation or one of {tuple(styles.animations.keys())}')
+            raise KeyError(f'Animation {frame!r} not found. Use None to remove animation or one of {tuple(styles.animations.keys())}')
             
     def set_animation(self, name):
         "Set animation of this slide. Provide None if need to stop animation."
         if name is None:
             self._animation = html('style', '')
         elif isinstance(name,str) and name in styles.animations:
-            self._animation = html('style',styles.animations[name])
+            self._animation = html('style',self._instance_animation(name))
             # See effect of changes
             if not self._app.running: # Otherwise it has side effects
                 if self._app._slidelabel != self.label:
@@ -450,27 +465,11 @@ class Slide:
                         display(self.animation, self._css)
         else:
             self._animation = None # It should be None, not '' or don't throw error here
-            
+       
     def _rebuild_all(self):
         "Update all slides in optimal way when a new slide is added."
-        self._app._iterable = self._app._collect_slides()
-        n_last = float(self._app._iterable[-1].label)
-        self._app._nslides = int(n_last) # Avoid frames number
-        self._app._max_index = len(self._app._iterable) - 1 # This includes all frames
-        
-        # Now update progress bar
-        opts = [(s.label, round(100*float(s.label)/(n_last or 1), 2)) for s in self._app._iterable]
-        self._app.progress_slider.options = opts  # update options
-        # Update Slides after progress bar is updated
-        self._app.widgets.slidebox.children = [it._widget for it in self._app._iterable]
+        self._app.refresh()
         self._app._slidelabel = self.label # Go there after setting children
-        
-        # Update display for slides with widgets
-        for i, s in enumerate(self._app._iterable):
-            s._index = i # Update index of slide for __repr__
-            if s._has_widgets:
-                s.update_display(go_there =  False) # Refresh all slides with widgets only, other data is not lost
-        
 
 @contextmanager
 def _build_slide(app, slide_number_str, is_frameless = True):
@@ -496,9 +495,8 @@ def _build_slide(app, slide_number_str, is_frameless = True):
             _slide._has_widgets = True
             break # No need to check other widgets if one exists
     
-    app._slidelabel = _slide.label # Go there to see effects
-    _slide.update_display() # Update Slide, it will not come to this point if has same code
-
+    _slide.update_display(go_there = True) # Update Slide, it will not come to this point if has same code
+    
     if old_slides != list(app._slides_dict.values()): # If there is a change in slides
         _slide._rebuild_all() # Rebuild all slides
         del old_slides # Delete old slides
