@@ -115,7 +115,7 @@ class Source:
         """Returns source object with `show_lines` and `focus_lines` methods. `name` is alternate used name for language.  
         `kwargs` are passed to `ipyslides.formatter.highlight`.     
         
-        (1.6.8+) tries to auto detect lanaguage from filename extension, if `language` is not given.
+        It tries to auto detect lanaguage from filename extension, if `language` is not given.
         """
         _title = name or filename
         _lang = language or os.path.splitext(filename)[-1].replace('.','')
@@ -151,13 +151,20 @@ class Source:
         ```python
         with source.context(auto_display = False) as s: #if not used as `s`, still it is stored `source.current` attribute.`
             do_something()
-            write(s) # or s.display(), iwrite(s)
+            write(s) # or s.display(), write(s)
             
         #s.raw, s.value are accesible attributes.
         #s.focus_lines, s.show_lines are methods that are used to show selective lines.
         ```
-        """  
-        frame = sys._getframe().f_back.f_back # go two steps back
+        """ 
+        frame = sys._getframe() 
+        depth = 2 # default depth is 2 to catch under itself, others would be given from differnt context managers to get their source.
+        if 'depth' in kwargs:
+            depth = kwargs.pop('depth')
+        
+        for _ in range(depth):
+            frame = frame.f_back # keep going back until required depth is reached.
+              
         lines, n1 = linecache.getlines(frame.f_code.co_filename), frame.f_lineno
         offset = 0 # going back to zero indent level
         while re.match('^\t?^\s+', lines[n1 - offset]): 
@@ -172,11 +179,7 @@ class Source:
                 with_node = node
                 break
 
-        if (sys.version_info.major >= 3) and (sys.version_info.minor >= 8):
-            n2 = with_node.body[-1].end_lineno #can include multiline expression
-        else: # if no next sibling node, pick by brute force for < 3.8
-            n2 = with_node.body[-1].lineno # multiline expressions can't be handled, just first line picked
-        
+        n2 = with_node.body[-1].end_lineno #can include multiline expressions in python 3.8+
         source = textwrap.dedent(''.join(lines[n1:][:n2 - offset]))
         source_html = _Source(highlight(source,language = 'python', **kwargs).value)
         source_html.raw = source # raw source code
